@@ -1,4 +1,4 @@
-#!/usr/bin/python2.7
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 from .dependency import Dependency
@@ -27,7 +27,7 @@ class Airodump(Dependency):
         if interface is None:
             interface = Configuration.interface
         if interface is None:
-            raise Exception("Wireless interface must be defined (-i)")
+            raise Exception('Wireless interface must be defined (-i)')
         self.interface = interface
 
         self.targets = []
@@ -137,7 +137,7 @@ class Airodump(Dependency):
             if fil.startswith('replay_') and fil.endswith('.cap') or fil.endswith('.xor'):
                 os.remove(os.path.join(temp_dir, fil))
 
-    def get_targets(self, apply_filter=True):
+    def get_targets(self, old_targets=[], apply_filter=True):
         ''' Parses airodump's CSV file, returns list of Targets '''
 
         # Find the .CSV file
@@ -150,13 +150,17 @@ class Airodump(Dependency):
             return self.targets  # No file found
 
         targets = Airodump.get_targets_from_csv(csv_filename)
+        for old_target in old_targets:
+            for target in targets:
+                if old_target.bssid == target.bssid:
+                    target.wps = old_target.wps
 
         # Check targets for WPS
         if not self.skip_wps:
             capfile = csv_filename[:-3] + 'cap'
             try:
                 Tshark.check_for_wps_and_update_targets(capfile, targets)
-            except Exception as e:
+            except ValueError:
                 # No tshark, or it failed. Fall-back to wash
                 Wash.check_for_wps_and_update_targets(capfile, targets)
 
@@ -178,9 +182,6 @@ class Airodump(Dependency):
                     new_target.decloaked = True
                     self.decloaked_bssids.add(new_target.bssid)
 
-        if self.pid.poll() is not None:
-            raise Exception('Airodump has stopped')
-
         self.targets = targets
         self.deauth_hidden_targets()
 
@@ -205,22 +206,22 @@ class Airodump(Dependency):
 
             hit_clients = False
             for row in csv_reader:
-                # Each "row" is a list of fields for a target/client
+                # Each 'row' is a list of fields for a target/client
 
                 if len(row) == 0: continue
 
                 if row[0].strip() == 'BSSID':
-                    # This is the "header" for the list of Targets
+                    # This is the 'header' for the list of Targets
                     hit_clients = False
                     continue
 
                 elif row[0].strip() == 'Station MAC':
-                    # This is the "header" for the list of Clients
+                    # This is the 'header' for the list of Clients
                     hit_clients = True
                     continue
 
                 if hit_clients:
-                    # The current row corresponds to a "Client" (computer)
+                    # The current row corresponds to a 'Client' (computer)
                     try:
                         client = Client(row)
                     except (IndexError, ValueError) as e:
@@ -238,7 +239,7 @@ class Airodump(Dependency):
                             break
 
                 else:
-                    # The current row corresponds to a "Target" (router)
+                    # The current row corresponds to a 'Target' (router)
                     try:
                         target = Target(row)
                         targets.append(target)
